==> excentis_xra31-3.1.0b0-py3-none-any.whl: excentis/xra31/xra31_configure.py <==
#!/usr/bin/env python3
"""
Command-line interface to :class:`~excentis.xra31.configuration.Configuration`.
"""

# pylint: disable=invalid-name
# pylint: disable=logging-format-interpolation
# pylint: disable=logging-not-lazy

import argparse
import json
import logging
import os
import sys

from excentis import xra31

# Arguments
parser = argparse.ArgumentParser(
    description="Configure the XRA-31 channels.  "
    "The three commands can be combined, and will be executed in the order "
    "store, load, wait-lock.")

parser.add_argument("address",
                    metavar="XRA-31",
                    help="XRA-31 hostname or IP address")

parser.add_argument("-f",
                    "--force",
                    action="store_true",
                    help="force full access mode if it's in use")
parser.add_argument("-q",
                    "--quiet",
                    action="store_true",
                    help="don't print progress messages")
parser.add_argument("-v",
                    "--verbose",
                    action="count",
                    help="print debugging messages")

parser_commands = parser.add_argument_group("commands")
parser_commands.add_argument(
    "--store",
    metavar="channels.json",
    help="store the current XRA-31 channel configuration to JSON",
    type=argparse.FileType('w'))
parser_commands.add_argument(
    "--load",
    metavar="channels.json",
    help="load a JSON channel configuration to the XRA-31",
    type=argparse.FileType('r'))
parser_commands.add_argument("--wait-lock",
                             action="store_true",
                             help="wait for all channels to be locked")

parser_options = parser.add_argument_group("command options")
parser_options.add_argument(
    "-t",
    "--timeout",
    help="maximum time to wait for lock and channel detection (seconds)",
    type=float)


def main():
    args = parser.parse_args()

    # Logging
    logger = logging.getLogger(os.path.basename(sys.argv[0]))
    logging.basicConfig(
        format="[%(asctime)s][%(name)s][%(levelname)s]: %(message)s")
    if args.verbose:
        logging.root.setLevel(logging.DEBUG)
        if args.verbose > 1:
            xra31.tracer.setLevel(logging.DEBUG)
        else:
            xra31.tracer.setLevel(logging.WARNING)
    elif not args.quiet:
        logger.setLevel(logging.INFO)

    # Connect
    try:
        client = xra31.connect(address=args.address)
    except xra31.exceptions.Xra31Exception as error:
        logger.error(
            "Could not connect to XRA-31 \"{}\". Please verify the host.{}{}".
            format(args.address, os.linesep, str(error)))
        sys.exit(1)

    logger.info("Connected to " + str(client))

    if args.verbose:
        client.logger.setLevel(logging.DEBUG)
    elif not args.quiet:
        client.logger.setLevel(logging.INFO)

    # Commands
    if args.store:
        logger.info("Store configuration in " + args.store.name)
        try:
            description = client.configuration.describe()
            json.dump(description, args.store, indent=4)
        except xra31.exceptions.Xra31Exception as error:
            logger.error("Could not store channel configuration: " +
                         str(error))
            sys.exit(1)

    if args.load:
        # Ensure full access available
        if not args.force:
            if not client.try_full_access():
                logger.error(
                    "Request for full access failed: "
                    "verify if no scripts or the web interface are in "
                    "full access mode, "
                    "or force full access with the option --force")
                sys.exit(1)
        # Verify capture activity
        if client.capture.active:
            logger.error(
                "Channel configuration can not be changed while capturing")
            sys.exit(1)
        with client:
            logger.info("Load configuration from " + args.load.name)
            description = json.load(args.load)
            try:
                client.configuration.apply(description, timeout=args.timeout)
            except xra31.exceptions.Xra31Exception as error:
                logger.error("Could not load channel configuration: " +
                             str(error))
                sys.exit(1)

    if args.wait_lock:
        for channel in client.configuration:
            if channel.state != xra31.ChannelState.LOCKED:
                logger.info("Wait for {} to lock...".format(str(channel)))
                if not client.configuration.wait_for_state(
                        channel,
                        state=xra31.ChannelState.LOCKED,
                        timeout=args.timeout):
                    logger.warning(
                        "Timeout while waiting for {} to lock".format(
                            str(channel)))
                    sys.exit(1)
            logger.info("{} locked".format(str(channel)))

==> excentis_xra31-4.0.0-py3-none-any.whl: excentis/xra31/xra31_configure.py <==
#!/usr/bin/env python3
"""
Command-line interface to :class:`~excentis.xra31.configuration.Configuration`.
"""

# pylint: disable=invalid-name
# pylint: disable=logging-format-interpolation
# pylint: disable=logging-not-lazy

import argparse
import json
import logging
import os
import pathlib
import sys

from excentis import xra31

# Arguments
parser = argparse.ArgumentParser(
    description="Configure the XRA-31 channels.  "
    "The three commands can be combined, and will be executed in the order "
    "store, load, wait-lock.")

parser.add_argument("address",
                    metavar="XRA-31",
                    help="XRA-31 hostname or IP address")

parser.add_argument("-f",
                    "--force",
                    action="store_true",
                    help="force full access mode if it's in use")
parser.add_argument("-q",
                    "--quiet",
                    action="store_true",
                    help="don't print progress messages")
parser.add_argument("-v",
                    "--verbose",
                    action="count",
                    help="print debugging messages")
parser.add_argument("--version",
                    action="store_true",
                    help="print client version and server release")

parser_commands = parser.add_argument_group("commands")
parser_commands.add_argument(
    "--store",
    metavar="channels.json",
    help="store the current XRA-31 channel configuration to JSON",
    type=argparse.FileType('w'))
parser_commands.add_argument(
    "--load",
    metavar="channels.json",
    help="load a JSON channel configuration to the XRA-31",
    type=argparse.FileType('r'))
parser_commands.add_argument("--wait-lock",
                             action="store_true",
                             help="wait for all channels to be locked")

parser_options = parser.add_argument_group("command options")
parser_options.add_argument(
    "-t",
    "--timeout",
    help="maximum time to wait for lock and channel detection (seconds)",
    type=float)


def main():
    args = parser.parse_args()

    # Logging
    logger = logging.getLogger(pathlib.Path(sys.argv[0]).name)
    logging.basicConfig(
        format="[%(asctime)s][%(name)s][%(levelname)s]: %(message)s")
    if args.verbose:
        logging.root.setLevel(logging.DEBUG)
        if args.verbose > 1:
            xra31.tracer.setLevel(logging.DEBUG)
        else:
            xra31.tracer.setLevel(logging.WARNING)
    elif not args.quiet:
        logger.setLevel(logging.INFO)

    # Connect
    try:
        client = xra31.connect(address=args.address)
    except xra31.exceptions.Xra31VersionException:
        # error logged by client
        sys.exit(1)
    except xra31.exceptions.Xra31Exception as error:
        logger.error("Could not connect to an XRA-31 at \"{}\"."
                     " Please verify the host.{}{}: {}".format(
                         args.address, os.linesep,
                         type(error).__name__, str(error)))
        sys.exit(1)

    logger.info("Connected to " + str(client))

    if args.verbose:
        client.logger.setLevel(logging.DEBUG)
    elif not args.quiet:
        client.logger.setLevel(logging.INFO)

    # Version
    if args.version:
        logger.info("Client version " + client.version)
        logger.info("XRA-31 release " + client.server_version)

    # Commands
    if args.store:
        logger.info("Store configuration in " + args.store.name)
        try:
            description = client.configuration.describe()
            json.dump(description, args.store, indent=4)
        except xra31.exceptions.Xra31Exception as error:
            logger.error("Could not store channel configuration: " +
                         str(error))
            sys.exit(1)

    if args.load:
        # Ensure full access available
        if not args.force:
            if not client.try_full_access():
                logger.error(
                    "Request for full access failed: "
                    "verify if no scripts or the web interface are in "
                    "full access mode, "
                    "or force full access with the option --force")
                sys.exit(1)
        # Verify capture activity
        if client.capture.active:
            logger.error(
                "Channel configuration can not be changed while capturing")
            sys.exit(1)
        with client:
            logger.info("Load configuration from " + args.load.name)
            description = json.load(args.load)
            try:
                client.configuration.apply(description, timeout=args.timeout)
            except xra31.exceptions.Xra31Exception as error:
                logger.error("Could not load channel configuration: " +
                             str(error))
                sys.exit(1)

    if args.wait_lock:
        for channel in client.configuration:
            if channel.state != xra31.ChannelState.LOCKED:
                logger.info("Wait for {} to lock...".format(str(channel)))
                if not client.configuration.wait_for_state(
                        channel,
                        state=xra31.ChannelState.LOCKED,
                        timeout=args.timeout):
                    logger.warning(
                        "Timeout while waiting for {} to lock".format(
                            str(channel)))
                    sys.exit(1)
            logger.info("{} locked".format(str(channel)))
